pywws
#####

Python software for USB Wireless WeatherStations.

pywws is a collection of Python modules to read, store and process data from popular USB wireless weather stations such as Elecsa AstroTouch 6975, Watson W-8681, WH-1080PC, WH1080, WH1081, WH3080 etc. I assume any model that is supplied with the EasyWeather Windows software is compatible, but cannot guarantee this.

The software has been developed to run in a low power, low memory environment such as a router or Raspberry Pi. It can be used to create graphs and web pages showing recent weather readings, typically updated every hour. It can also send "live" data to services such as `Weather Underground <http://www.wunderground.com/>`_ and post messages to `Twitter <https://twitter.com/>`_.

The development version of pywws is hosted on GitHub.
   * https://github.com/jim-easterbrook/pywws

"Snapshot" releases of pywws are available from the Python Package Index (PyPI).
   * https://pypi.python.org/pypi/pywws

Documentation is hosted on Read the Docs.
   * http://pywws.readthedocs.org/